@@ -5,7 +5,7 @@ use warnings;
 use strict;
 use 5.014;
 
-our $VERSION = '2.308';
+our $VERSION = '2.309';
 
 #use bytes; # required
 use Scalar::Util qw( looks_like_number );
@@ -81,18 +81,25 @@ sub get_schemas {
             $user_schema = [ 'main' ]; # [ undef ];
         }
         elsif( $driver =~ /^(?:mysql|MariaDB)\z/ ) {
-            # MySQL 5.7 Reference Manual  /  MySQL Glossary:
+            # MySQL 8.0 Reference Manual / MySQL Glossary / Schema:
             # In MySQL, physically, a schema is synonymous with a database.
             # You can substitute the keyword SCHEMA instead of DATABASE in MySQL SQL syntax,
             $user_schema = [ $db ];
         }
-        elsif( $driver eq 'Pg' ) {
-            my $sth = $dbh->table_info( undef, '%', undef, undef );
+        else {
             # 'pg_schema' holds the unquoted name of the schema
-            my $info = $sth->fetchall_hashref( 'pg_schema' );
-            my $qr = qr/^(?:pg_|information_schema$)/;
+            my $TABLE_SCHEM = $driver eq 'Pg' ? 'pg_schema' : 'TABLE_SCHEM';
+            my $regex_sys;
+            if ( $driver eq 'Pg' ) {
+                $regex_sys = qr/^(?:pg_|information_schema$)/;
+            }
+            elsif ( $driver eq 'DB2' ) {
+                $regex_sys = qr/^(?:SYS|SQLJ$|NULLID$)/;
+            }
+            my $sth = $dbh->table_info( undef, '%', '', '' );
+            my $info = $sth->fetchall_hashref( $TABLE_SCHEM );
             for my $schema ( keys %$info ) {
-                if ( $schema =~ /$qr/ ) {
+                if ( defined $regex_sys && $schema =~ $regex_sys ) {
                     push @$sys_schema, $schema;
                 }
                 else {
@@ -100,11 +107,6 @@ sub get_schemas {
                 }
             }
         }
-        else {
-            my $sth = $dbh->table_info( undef, '%', undef, undef );
-            my $info = $sth->fetchall_hashref( 'TABLE_SCHEM' );
-            $user_schema = [ keys %$info ];
-        }
     }
     $user_schema = [] if ! defined $user_schema;
     $sys_schema  = [] if ! defined $sys_schema;
@@ -177,7 +179,7 @@ sub tables_info { # not public
         $table_name  = 'TABLE_NAME';
     }
     my @keys = ( 'TABLE_CAT', $table_schem, $table_name, 'TABLE_TYPE' );
-    my $sth = $dbh->table_info( undef, $schema, undef, undef );
+    my $sth = $dbh->table_info( undef, $schema, '%', '' );
     my $info_tables = $sth->fetchall_arrayref( { map { $_ => 1 } @keys } );
     my %equal_table_names;
     for my $info_table ( @$info_tables ) {
@@ -271,7 +273,7 @@ sub primary_key_autoincrement_constraint {
         my ( $pg_version ) = $dbh->selectrow_array( "SELECT version()" );
         if ( $pg_version =~ /^\S+\s+([0-9]+)(?:\.[0-9]+)*\s/ && $1 >= 10 ) {
             # since PostgreSQL version 10
-            return "INT generated BY DEFAULT AS IDENTITY PRIMARY KEY";
+            return "INT GENERATED BY DEFAULT AS IDENTITY PRIMARY KEY";
         }
         else {
             return "SERIAL PRIMARY KEY";
@@ -290,7 +292,7 @@ sub primary_key_autoincrement_constraint {
 }
 
 
-# db2 and oracle untested
+
 
 
 1;
@@ -308,7 +310,7 @@ App::DBBrowser::DB - Database plugin documentation.
 
 =head1 VERSION
 
-Version 2.308
+Version 2.309
 
 =head1 DESCRIPTION
 
